package com.sun.xml.internal.ws.developer;

import java.util.Iterator;
import com.sun.istack.internal.NotNull;
import java.util.ArrayList;
import javax.xml.transform.Source;
import com.sun.xml.internal.ws.api.message.Header;
import java.util.List;

public final class EPRRecipe
{
    private final List<Header> referenceParameters;
    private final List<Source> metadata;
    
    public EPRRecipe() {
        this.referenceParameters = new ArrayList();
        this.metadata = new ArrayList();
    }
    
    @NotNull
    public List<Header> getReferenceParameters() {
        return this.referenceParameters;
    }
    
    @NotNull
    public List<Source> getMetadata() {
        return this.metadata;
    }
    
    public EPRRecipe addReferenceParameter(Header h) {
        if (h == null) {
            throw new IllegalArgumentException();
        }
        this.referenceParameters.add(h);
        return this;
    }
    
    public EPRRecipe addReferenceParameters(Header... headers) {
        for (Header h : headers) {
            this.addReferenceParameter(h);
        }
        return this;
    }
    
    public EPRRecipe addReferenceParameters(Iterable<? extends Header> headers) {
        for (Header h : headers) {
            this.addReferenceParameter(h);
        }
        return this;
    }
    
    public EPRRecipe addMetadata(Source source) {
        if (source == null) {
            throw new IllegalArgumentException();
        }
        this.metadata.add(source);
        return this;
    }
    
    public EPRRecipe addMetadata(Source... sources) {
        for (Source s : sources) {
            this.addMetadata(s);
        }
        return this;
    }
    
    public EPRRecipe addMetadata(Iterable<? extends Source> sources) {
        for (Source s : sources) {
            this.addMetadata(s);
        }
        return this;
    }
}
